Class: BigcommerceOAuthAPI::Client
- Defined in:
- lib/bigcommerce-oauth-api/client.rb
Instance Method Summary collapse
-
#banner(id, options = {}) ⇒ Object
gets the banner with the given id.
-
#banners(options = {}) ⇒ Object
gets a list of banners.
-
#blog_post(id, options = {}) ⇒ Object
gets the blog post with the given id.
-
#blog_posts(options = {}) ⇒ Object
gets a list of blog posts.
-
#blog_tags(options = {}) ⇒ Object
gets a list of blog tags.
-
#brand(id, options = {}) ⇒ Object
gets the brand with the given id.
-
#brands(options = {}) ⇒ Object
gets a list of brands.
-
#brands_count(options = {}) ⇒ Object
returns the number of brands.
-
#categories(options = {}) ⇒ Object
gets a list of categories.
-
#category(id, options = {}) ⇒ Object
gets the category with the given id.
-
#countries(options = {}) ⇒ Object
gets a list of countries.
-
#countries_count(options = {}) ⇒ Object
returns the number of countries.
-
#country(id, options = {}) ⇒ Object
gets the country with the given id.
-
#country_state(country_id, id, options = {}) ⇒ Object
gets the state with the given id for the given country.
-
#country_states(country_id, options = {}) ⇒ Object
gets a list of states for the given country.
-
#country_states_count(country_id, options = {}) ⇒ Object
returns the number of states for the given country.
-
#coupon(id, options = {}) ⇒ Object
gets the coupon with the given id.
-
#coupons(options = {}) ⇒ Object
gets a list of coupons.
-
#coupons_count(options = {}) ⇒ Object
returns the number of coupons.
-
#create_banner(options = {}) ⇒ Object
creates a banner with the given attributes.
-
#create_blog_post(options = {}) ⇒ Object
creates a blog post with the given attributes.
-
#create_brand(options = {}) ⇒ Object
creates a brand with the given attributes.
-
#create_category(options = {}) ⇒ Object
creates a category with the given attributes.
-
#create_coupon(options = {}) ⇒ Object
creates a coupon with the given attributes.
-
#create_customer(options = {}) ⇒ Object
creates a customer with the given attributes.
-
#create_customer_address(customer_id, options = {}) ⇒ Object
creates a address with the given attributes for the given customer.
-
#create_customer_group(options = {}) ⇒ Object
creates a customer_group with the given attributes.
-
#create_gift_certificate(options = {}) ⇒ Object
creates a gift_certificate with the given attributes.
-
#create_hook(options = {}) ⇒ Object
creates a hook with the given attributes.
-
#create_option(options = {}) ⇒ Object
creates a option with the given attributes.
-
#create_option_set(options = {}) ⇒ Object
creates a option_set with the given attributes.
-
#create_option_set_option(option_set_id, options = {}) ⇒ Object
creates a option with the given attributes for the given option_set.
-
#create_option_value(option_id, options = {}) ⇒ Object
creates a value with the given attributes for the given option.
-
#create_order(options = {}) ⇒ Object
creates a order with the given attributes.
-
#create_order_shipment(order_id, options = {}) ⇒ Object
creates a shipment with the given attributes for the given order.
-
#create_product(options = {}) ⇒ Object
creates a product with the given attributes.
-
#create_product_custom_field(product_id, options = {}) ⇒ Object
creates a custom_field with the given attributes for the given product.
-
#create_product_discount_rule(product_id, options = {}) ⇒ Object
creates a discount_rule with the given attributes for the given product.
-
#create_product_image(product_id, options = {}) ⇒ Object
creates a image with the given attributes for the given product.
-
#create_product_rule(product_id, options = {}) ⇒ Object
creates a rule with the given attributes for the given product.
-
#create_product_sku(product_id, options = {}) ⇒ Object
creates a sku with the given attributes for the given product.
-
#create_product_video(product_id, options = {}) ⇒ Object
creates a video with the given attributes for the given product.
-
#create_redirect(options = {}) ⇒ Object
creates a redirect with the given attributes.
-
#create_shipping_zone(options = {}) ⇒ Object
creates a shipping zone with the given attributes.
-
#create_shipping_zone_method(zone_id, options = {}) ⇒ Object
creates a shipping method with the given attributes for the given shipping zone.
-
#customer(id, options = {}) ⇒ Object
gets the customer with the given id.
-
#customer_address(customer_id, id, options = {}) ⇒ Object
gets the address with the given id for the given customer.
-
#customer_addresses(customer_id, options = {}) ⇒ Object
gets a list of addresses for the given customer.
-
#customer_group(id, options = {}) ⇒ Object
gets the customer_group with the given id.
-
#customer_groups(options = {}) ⇒ Object
gets a list of customer_groups.
-
#customers(options = {}) ⇒ Object
gets a list of customers.
-
#customers_count(options = {}) ⇒ Object
returns the number of customers.
-
#delete_banner(id) ⇒ Object
deletes the banner with the given id.
-
#delete_blog_post(id) ⇒ Object
deletes the blog post with the given id.
-
#delete_brand(id) ⇒ Object
deletes the brand with the given id.
-
#delete_category(id) ⇒ Object
deletes the category with the given id.
-
#delete_coupon(id) ⇒ Object
deletes the coupon with the given id.
-
#delete_customer(id) ⇒ Object
deletes the customer with the given id.
-
#delete_customer_address(customer_id, id) ⇒ Object
deletes the address with the given id for the given customer.
-
#delete_customer_group(id) ⇒ Object
deletes the customer_group with the given id.
-
#delete_gift_certificate(id) ⇒ Object
deletes the gift_certificate with the given id.
-
#delete_hook(id) ⇒ Object
deletes the hook with the given id.
-
#delete_option(id) ⇒ Object
deletes the option with the given id.
-
#delete_option_set(id) ⇒ Object
deletes the option_set with the given id.
-
#delete_option_set_option(option_set_id, id) ⇒ Object
deletes the option with the given id for the given option_set.
-
#delete_option_value(option_id, id) ⇒ Object
deletes the value with the given id for the given option.
-
#delete_order(id) ⇒ Object
deletes the order with the given id.
-
#delete_order_shipment(order_id, id) ⇒ Object
deletes the shipment with the given id for the given order.
-
#delete_product(id) ⇒ Object
deletes the product with the given id.
-
#delete_product_configurable_field(product_id, id) ⇒ Object
deletes the configurable_field with the given id for the given product.
-
#delete_product_custom_field(product_id, id) ⇒ Object
deletes the custom_field with the given id for the given product.
-
#delete_product_discount_rule(product_id, id) ⇒ Object
deletes the discount_rule with the given id for the given product.
-
#delete_product_image(product_id, id) ⇒ Object
deletes the image with the given id for the given product.
-
#delete_product_rule(product_id, id) ⇒ Object
deletes the rule with the given id for the given product.
-
#delete_product_sku(product_id, id) ⇒ Object
deletes the sku with the given id for the given product.
-
#delete_product_video(product_id, id) ⇒ Object
deletes the video with the given id for the given product.
-
#delete_redirect(id) ⇒ Object
deletes the redirect with the given id.
-
#delete_shipping_zone(id) ⇒ Object
deletes the shipping zone with the given id.
-
#delete_shipping_zone_method(zone_id, id) ⇒ Object
deletes the shipping method with the given id for the given shipping zone.
-
#gift_certificate(id, options = {}) ⇒ Object
gets the gift_certificate with the given id.
-
#gift_certificates(options = {}) ⇒ Object
gets a list of gift_certificates.
-
#hook(id, options = {}) ⇒ Object
gets the hook with the given id.
-
#hooks(options = {}) ⇒ Object
gets a list of hooks.
-
#option(id, options = {}) ⇒ Object
gets the option with the given id.
-
#option_set(id, options = {}) ⇒ Object
gets the option_set with the given id.
-
#option_set_option(option_set_id, id, options = {}) ⇒ Object
gets the option with the given id for the given option_set.
-
#option_set_options(option_set_id, options = {}) ⇒ Object
gets a list of options for the given option_set.
-
#option_sets(options = {}) ⇒ Object
gets a list of option_sets.
-
#option_sets_count(options = {}) ⇒ Object
returns the number of option_sets.
-
#option_value(option_id, id, options = {}) ⇒ Object
gets the value with the given id for the given option.
-
#option_values(option_id, options = {}) ⇒ Object
gets a list of values for the given option.
-
#options(options = {}) ⇒ Object
gets a list of options.
-
#options_count(options = {}) ⇒ Object
returns the number of options.
-
#order(id, options = {}) ⇒ Object
gets the order with the given id.
-
#order_coupon(order_id, id, options = {}) ⇒ Object
gets the coupon with the given id for the given order.
-
#order_coupons(order_id, options = {}) ⇒ Object
gets a list of coupons for the given order.
-
#order_message(order_id, id, options = {}) ⇒ Object
gets the message with the given id for the given order.
-
#order_messages(order_id, options = {}) ⇒ Object
gets a list of messages for the given order.
-
#order_product(order_id, id, options = {}) ⇒ Object
gets the product with the given id for the given order.
-
#order_products(order_id, options = {}) ⇒ Object
gets a list of products for the given order.
-
#order_products_count(order_id, options = {}) ⇒ Object
returns the number of products for the given order.
-
#order_shipment(order_id, id, options = {}) ⇒ Object
gets the shipment with the given id for the given order.
-
#order_shipments(order_id, options = {}) ⇒ Object
gets a list of shipments for the given order.
-
#order_shipping_address(order_id, id, options = {}) ⇒ Object
gets the shipping_address with the given id for the given order.
-
#order_shipping_addresses(order_id, options = {}) ⇒ Object
gets a list of shipping_addresses for the given order.
-
#order_status(id, options = {}) ⇒ Object
gets the order_status with the given id.
-
#order_statuses(options = {}) ⇒ Object
gets a list of order_statuses.
-
#order_tax(order_id, id, options = {}) ⇒ Object
gets the tax with the given id for the given order.
-
#order_taxes(order_id, options = {}) ⇒ Object
gets a list of taxes for the given order.
-
#orders(options = {}) ⇒ Object
gets a list of orders.
-
#orders_count(options = {}) ⇒ Object
returns the number of orders.
-
#payment_methods(options = {}) ⇒ Object
gets a list of payment methods.
-
#product(id, options = {}) ⇒ Object
gets the product with the given id.
-
#product_configurable_field(product_id, id, options = {}) ⇒ Object
gets the configurable_field with the given id for the given product.
-
#product_configurable_fields(product_id, options = {}) ⇒ Object
gets a list of configurable_fields for the given product.
-
#product_configurable_fields_count(product_id, options = {}) ⇒ Object
returns the number of configurable_fields for the given product.
-
#product_custom_field(product_id, id, options = {}) ⇒ Object
gets the custom_field with the given id for the given product.
-
#product_custom_fields(product_id, options = {}) ⇒ Object
gets a list of custom_fields for the given product.
-
#product_discount_rule(product_id, id, options = {}) ⇒ Object
gets the discount_rule with the given id for the given product.
-
#product_discount_rules(product_id, options = {}) ⇒ Object
gets a list of discount_rules for the given product.
-
#product_discount_rules_count(product_id, options = {}) ⇒ Object
returns the number of discount_rules for the given product.
-
#product_googleproductsearch(product_id, options = {}) ⇒ Object
Gets the Google Product Search mappings for a product.
-
#product_image(product_id, id, options = {}) ⇒ Object
gets the image with the given id for the given product.
-
#product_images(product_id, options = {}) ⇒ Object
gets a list of images for the given product.
-
#product_images_count(product_id, options = {}) ⇒ Object
returns the number of images for the given product.
-
#product_option(product_id, id, options = {}) ⇒ Object
gets the option with the given id for the given product.
-
#product_options(product_id, options = {}) ⇒ Object
gets a list of options for the given product.
-
#product_reviews(product_id, options = {}) ⇒ Object
gets a list of reviews for the given product.
-
#product_rule(product_id, id, options = {}) ⇒ Object
gets the rule with the given id for the given product.
-
#product_rules(product_id, options = {}) ⇒ Object
gets a list of rules for the given product.
-
#product_rules_count(product_id, options = {}) ⇒ Object
returns the number of rules for the given product.
-
#product_sku(product_id, id, options = {}) ⇒ Object
gets the sku with the given id for the given product.
-
#product_skus(product_id, options = {}) ⇒ Object
gets a list of skus for the given product.
-
#product_skus_count(product_id, options = {}) ⇒ Object
returns the number of skus for the given product.
-
#product_video(product_id, id, options = {}) ⇒ Object
gets the video with the given id for the given product.
-
#product_videos(product_id, options = {}) ⇒ Object
gets a list of videos for the given product.
-
#product_videos_count(product_id, options = {}) ⇒ Object
returns the number of videos for the given product.
-
#products(options = {}) ⇒ Object
gets a list of products.
-
#products_count(options = {}) ⇒ Object
returns the number of products.
-
#redirect(id, options = {}) ⇒ Object
gets the redirect with the given id.
-
#redirects(options = {}) ⇒ Object
gets a list of redirects.
-
#redirects_count(options = {}) ⇒ Object
returns the number of redirects.
-
#shipping_zone(id, options = {}) ⇒ Object
gets the shipping zone with the given id.
-
#shipping_zone_method(zone_id, id, options = {}) ⇒ Object
gets the shipping method with the given id for the given shipping zone.
-
#shipping_zone_methods(zone_id, options = {}) ⇒ Object
gets a list of shipping methods for the given shipping zone.
-
#shipping_zones(options = {}) ⇒ Object
gets a list of shipping zones.
-
#store_information ⇒ Object
get basic store information.
-
#tax_class(id, options = {}) ⇒ Object
gets the tax_class with the given id.
-
#tax_classes(options = {}) ⇒ Object
gets a list of tax_classes.
-
#time ⇒ Object
get server time.
-
#update_banner(id, options = {}) ⇒ Object
updates the attributes of the banner with the given id.
-
#update_blog_post(id, options = {}) ⇒ Object
updates the attributes of the blog post with the given id.
-
#update_brand(id, options = {}) ⇒ Object
updates the attributes of the brand with the given id.
-
#update_category(id, options = {}) ⇒ Object
updates the attributes of the category with the given id.
-
#update_coupon(id, options = {}) ⇒ Object
updates the attributes of the coupon with the given id.
-
#update_customer(id, options = {}) ⇒ Object
updates the attributes of the customer with the given id.
-
#update_customer_address(customer_id, id, options = {}) ⇒ Object
updates the attributes of the address with the given id for the given customer.
-
#update_customer_group(id, options = {}) ⇒ Object
updates the attributes of the customer_group with the given id.
-
#update_gift_certificate(id, options = {}) ⇒ Object
updates the attributes of the gift_certificate with the given id.
-
#update_hook(id, options = {}) ⇒ Object
updates the attributes of the hook with the given id.
-
#update_option(id, options = {}) ⇒ Object
updates the attributes of the option with the given id.
-
#update_option_set(id, options = {}) ⇒ Object
updates the attributes of the option_set with the given id.
-
#update_option_set_option(option_set_id, id, options = {}) ⇒ Object
updates the attributes of the option with the given id for the given option_set.
-
#update_option_value(option_id, id, options = {}) ⇒ Object
updates the attributes of the value with the given id for the given option.
-
#update_order(id, options = {}) ⇒ Object
updates the attributes of the order with the given id.
-
#update_order_shipment(order_id, id, options = {}) ⇒ Object
updates the attributes of the shipment with the given id for the given order.
-
#update_product(id, options = {}) ⇒ Object
updates the attributes of the product with the given id.
-
#update_product_custom_field(product_id, id, options = {}) ⇒ Object
updates the attributes of the custom_field with the given id for the given product.
-
#update_product_discount_rule(product_id, id, options = {}) ⇒ Object
updates the attributes of the discount_rule with the given id for the given product.
-
#update_product_image(product_id, id, options = {}) ⇒ Object
updates the attributes of the image with the given id for the given product.
-
#update_product_rule(product_id, id, options = {}) ⇒ Object
updates the attributes of the rule with the given id for the given product.
-
#update_product_sku(product_id, id, options = {}) ⇒ Object
updates the attributes of the sku with the given id for the given product.
-
#update_product_video(product_id, id, options = {}) ⇒ Object
updates the attributes of the video with the given id for the given product.
-
#update_redirect(id, options = {}) ⇒ Object
updates the attributes of the redirect with the given id.
-
#update_shipping_zone(id, options = {}) ⇒ Object
updates the attributes of the shipping zone with the given id.
-
#update_shipping_zone_method(zone_id, id, options = {}) ⇒ Object
updates the attributes of the shipping method with the given id for the given shipping zone.
Methods inherited from API
#config, #initialize, #is_legacy?
Methods included from Request
Constructor Details
This class inherits a constructor from BigcommerceOAuthAPI::API
Instance Method Details
#banner(id, options = {}) ⇒ Object
gets the banner with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 239
|
#banners(options = {}) ⇒ Object
gets a list of banners
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 235
|
#blog_post(id, options = {}) ⇒ Object
gets the blog post with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 69
|
#blog_posts(options = {}) ⇒ Object
gets a list of blog posts
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 65
|
#blog_tags(options = {}) ⇒ Object
gets a list of blog tags
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 86
|
#brand(id, options = {}) ⇒ Object
gets the brand with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 94
|
#brands(options = {}) ⇒ Object
gets a list of brands
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 90
|
#brands_count(options = {}) ⇒ Object
returns the number of brands
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 111
|
#categories(options = {}) ⇒ Object
gets a list of categories
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 115
|
#category(id, options = {}) ⇒ Object
gets the category with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 119
|
#countries(options = {}) ⇒ Object
gets a list of countries
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 208
|
#countries_count(options = {}) ⇒ Object
returns the number of countries
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 216
|
#country(id, options = {}) ⇒ Object
gets the country with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 212
|
#country_state(country_id, id, options = {}) ⇒ Object
gets the state with the given id for the given country
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 225
|
#country_states(country_id, options = {}) ⇒ Object
gets a list of states for the given country
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 220
|
#country_states_count(country_id, options = {}) ⇒ Object
returns the number of states for the given country
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 230
|
#coupon(id, options = {}) ⇒ Object
gets the coupon with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 260
|
#coupons(options = {}) ⇒ Object
gets a list of coupons
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 256
|
#coupons_count(options = {}) ⇒ Object
returns the number of coupons
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 277
|
#create_banner(options = {}) ⇒ Object
creates a banner with the given attributes
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 243
|
#create_blog_post(options = {}) ⇒ Object
creates a blog post with the given attributes
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 73
|
#create_brand(options = {}) ⇒ Object
creates a brand with the given attributes
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 98
|
#create_category(options = {}) ⇒ Object
creates a category with the given attributes
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 123
|
#create_coupon(options = {}) ⇒ Object
creates a coupon with the given attributes
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 264
|
#create_customer(options = {}) ⇒ Object
creates a customer with the given attributes
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 144
|
#create_customer_address(customer_id, options = {}) ⇒ Object
creates a address with the given attributes for the given customer
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 171
|
#create_customer_group(options = {}) ⇒ Object
creates a customer_group with the given attributes
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 195
|
#create_gift_certificate(options = {}) ⇒ Object
creates a gift_certificate with the given attributes
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 289
|
#create_hook(options = {}) ⇒ Object
creates a hook with the given attributes
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 851
|
#create_option(options = {}) ⇒ Object
creates a option with the given attributes
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 310
|
#create_option_set(options = {}) ⇒ Object
creates a option_set with the given attributes
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 335
|
#create_option_set_option(option_set_id, options = {}) ⇒ Object
creates a option with the given attributes for the given option_set
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 362
|
#create_option_value(option_id, options = {}) ⇒ Object
creates a value with the given attributes for the given option
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 388
|
#create_order(options = {}) ⇒ Object
creates a order with the given attributes
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 420
|
#create_order_shipment(order_id, options = {}) ⇒ Object
creates a shipment with the given attributes for the given order
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 482
|
#create_product(options = {}) ⇒ Object
creates a product with the given attributes
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 530
|
#create_product_custom_field(product_id, options = {}) ⇒ Object
creates a custom_field with the given attributes for the given product
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 557
|
#create_product_discount_rule(product_id, options = {}) ⇒ Object
creates a discount_rule with the given attributes for the given product
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 583
|
#create_product_image(product_id, options = {}) ⇒ Object
creates a image with the given attributes for the given product
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 634
|
#create_product_rule(product_id, options = {}) ⇒ Object
creates a rule with the given attributes for the given product
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 680
|
#create_product_sku(product_id, options = {}) ⇒ Object
creates a sku with the given attributes for the given product
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 742
|
#create_product_video(product_id, options = {}) ⇒ Object
creates a video with the given attributes for the given product
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 711
|
#create_redirect(options = {}) ⇒ Object
creates a redirect with the given attributes
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 771
|
#create_shipping_zone(options = {}) ⇒ Object
creates a shipping zone with the given attributes
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 822
|
#create_shipping_zone_method(zone_id, options = {}) ⇒ Object
creates a shipping method with the given attributes for the given shipping zone
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 798
|
#customer(id, options = {}) ⇒ Object
gets the customer with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 140
|
#customer_address(customer_id, id, options = {}) ⇒ Object
gets the address with the given id for the given customer
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 166
|
#customer_addresses(customer_id, options = {}) ⇒ Object
gets a list of addresses for the given customer
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 161
|
#customer_group(id, options = {}) ⇒ Object
gets the customer_group with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 191
|
#customer_groups(options = {}) ⇒ Object
gets a list of customer_groups
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 187
|
#customers(options = {}) ⇒ Object
gets a list of customers
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 136
|
#customers_count(options = {}) ⇒ Object
returns the number of customers
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 157
|
#delete_banner(id) ⇒ Object
deletes the banner with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 252
|
#delete_blog_post(id) ⇒ Object
deletes the blog post with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 82
|
#delete_brand(id) ⇒ Object
deletes the brand with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 107
|
#delete_category(id) ⇒ Object
deletes the category with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 132
|
#delete_coupon(id) ⇒ Object
deletes the coupon with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 273
|
#delete_customer(id) ⇒ Object
deletes the customer with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 153
|
#delete_customer_address(customer_id, id) ⇒ Object
deletes the address with the given id for the given customer
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 182
|
#delete_customer_group(id) ⇒ Object
deletes the customer_group with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 204
|
#delete_gift_certificate(id) ⇒ Object
deletes the gift_certificate with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 298
|
#delete_hook(id) ⇒ Object
deletes the hook with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 860
|
#delete_option(id) ⇒ Object
deletes the option with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 319
|
#delete_option_set(id) ⇒ Object
deletes the option_set with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 344
|
#delete_option_set_option(option_set_id, id) ⇒ Object
deletes the option with the given id for the given option_set
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 373
|
#delete_option_value(option_id, id) ⇒ Object
deletes the value with the given id for the given option
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 399
|
#delete_order(id) ⇒ Object
deletes the order with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 429
|
#delete_order_shipment(order_id, id) ⇒ Object
deletes the shipment with the given id for the given order
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 493
|
#delete_product(id) ⇒ Object
deletes the product with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 539
|
#delete_product_configurable_field(product_id, id) ⇒ Object
deletes the configurable_field with the given id for the given product
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 614
|
#delete_product_custom_field(product_id, id) ⇒ Object
deletes the custom_field with the given id for the given product
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 568
|
#delete_product_discount_rule(product_id, id) ⇒ Object
deletes the discount_rule with the given id for the given product
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 594
|
#delete_product_image(product_id, id) ⇒ Object
deletes the image with the given id for the given product
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 645
|
#delete_product_rule(product_id, id) ⇒ Object
deletes the rule with the given id for the given product
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 691
|
#delete_product_sku(product_id, id) ⇒ Object
deletes the sku with the given id for the given product
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 753
|
#delete_product_video(product_id, id) ⇒ Object
deletes the video with the given id for the given product
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 722
|
#delete_redirect(id) ⇒ Object
deletes the redirect with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 780
|
#delete_shipping_zone(id) ⇒ Object
deletes the shipping zone with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 831
|
#delete_shipping_zone_method(zone_id, id) ⇒ Object
deletes the shipping method with the given id for the given shipping zone
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 809
|
#gift_certificate(id, options = {}) ⇒ Object
gets the gift_certificate with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 285
|
#gift_certificates(options = {}) ⇒ Object
gets a list of gift_certificates
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 281
|
#hook(id, options = {}) ⇒ Object
gets the hook with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 847
|
#hooks(options = {}) ⇒ Object
gets a list of hooks
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 843
|
#option(id, options = {}) ⇒ Object
gets the option with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 306
|
#option_set(id, options = {}) ⇒ Object
gets the option_set with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 331
|
#option_set_option(option_set_id, id, options = {}) ⇒ Object
gets the option with the given id for the given option_set
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 357
|
#option_set_options(option_set_id, options = {}) ⇒ Object
gets a list of options for the given option_set
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 352
|
#option_sets(options = {}) ⇒ Object
gets a list of option_sets
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 327
|
#option_sets_count(options = {}) ⇒ Object
returns the number of option_sets
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 348
|
#option_value(option_id, id, options = {}) ⇒ Object
gets the value with the given id for the given option
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 383
|
#option_values(option_id, options = {}) ⇒ Object
gets a list of values for the given option
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 378
|
#options(options = {}) ⇒ Object
gets a list of options
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 302
|
#options_count(options = {}) ⇒ Object
returns the number of options
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 323
|
#order(id, options = {}) ⇒ Object
gets the order with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 416
|
#order_coupon(order_id, id, options = {}) ⇒ Object
gets the coupon with the given id for the given order
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 442
|
#order_coupons(order_id, options = {}) ⇒ Object
gets a list of coupons for the given order
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 437
|
#order_message(order_id, id, options = {}) ⇒ Object
gets the message with the given id for the given order
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 452
|
#order_messages(order_id, options = {}) ⇒ Object
gets a list of messages for the given order
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 447
|
#order_product(order_id, id, options = {}) ⇒ Object
gets the product with the given id for the given order
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 462
|
#order_products(order_id, options = {}) ⇒ Object
gets a list of products for the given order
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 457
|
#order_products_count(order_id, options = {}) ⇒ Object
returns the number of products for the given order
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 467
|
#order_shipment(order_id, id, options = {}) ⇒ Object
gets the shipment with the given id for the given order
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 477
|
#order_shipments(order_id, options = {}) ⇒ Object
gets a list of shipments for the given order
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 472
|
#order_shipping_address(order_id, id, options = {}) ⇒ Object
gets the shipping_address with the given id for the given order
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 503
|
#order_shipping_addresses(order_id, options = {}) ⇒ Object
gets a list of shipping_addresses for the given order
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 498
|
#order_status(id, options = {}) ⇒ Object
gets the order_status with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 408
|
#order_statuses(options = {}) ⇒ Object
gets a list of order_statuses
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 404
|
#order_tax(order_id, id, options = {}) ⇒ Object
gets the tax with the given id for the given order
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 513
|
#order_taxes(order_id, options = {}) ⇒ Object
gets a list of taxes for the given order
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 508
|
#orders(options = {}) ⇒ Object
gets a list of orders
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 412
|
#orders_count(options = {}) ⇒ Object
returns the number of orders
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 433
|
#payment_methods(options = {}) ⇒ Object
gets a list of payment methods
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 518
|
#product(id, options = {}) ⇒ Object
gets the product with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 526
|
#product_configurable_field(product_id, id, options = {}) ⇒ Object
gets the configurable_field with the given id for the given product
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 609
|
#product_configurable_fields(product_id, options = {}) ⇒ Object
gets a list of configurable_fields for the given product
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 604
|
#product_configurable_fields_count(product_id, options = {}) ⇒ Object
returns the number of configurable_fields for the given product
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 619
|
#product_custom_field(product_id, id, options = {}) ⇒ Object
gets the custom_field with the given id for the given product
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 552
|
#product_custom_fields(product_id, options = {}) ⇒ Object
gets a list of custom_fields for the given product
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 547
|
#product_discount_rule(product_id, id, options = {}) ⇒ Object
gets the discount_rule with the given id for the given product
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 578
|
#product_discount_rules(product_id, options = {}) ⇒ Object
gets a list of discount_rules for the given product
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 573
|
#product_discount_rules_count(product_id, options = {}) ⇒ Object
returns the number of discount_rules for the given product
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 599
|
#product_googleproductsearch(product_id, options = {}) ⇒ Object
Gets the Google Product Search mappings for a product.
20 21 22 |
# File 'lib/bigcommerce-oauth-api/client.rb', line 20 def product_googleproductsearch(product_id, = {}) get("products/#{product_id}/googleproductsearch", ) end |
#product_image(product_id, id, options = {}) ⇒ Object
gets the image with the given id for the given product
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 629
|
#product_images(product_id, options = {}) ⇒ Object
gets a list of images for the given product
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 624
|
#product_images_count(product_id, options = {}) ⇒ Object
returns the number of images for the given product
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 650
|
#product_option(product_id, id, options = {}) ⇒ Object
gets the option with the given id for the given product
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 660
|
#product_options(product_id, options = {}) ⇒ Object
gets a list of options for the given product
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 655
|
#product_reviews(product_id, options = {}) ⇒ Object
gets a list of reviews for the given product
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 665
|
#product_rule(product_id, id, options = {}) ⇒ Object
gets the rule with the given id for the given product
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 675
|
#product_rules(product_id, options = {}) ⇒ Object
gets a list of rules for the given product
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 670
|
#product_rules_count(product_id, options = {}) ⇒ Object
returns the number of rules for the given product
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 696
|
#product_sku(product_id, id, options = {}) ⇒ Object
gets the sku with the given id for the given product
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 737
|
#product_skus(product_id, options = {}) ⇒ Object
gets a list of skus for the given product
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 732
|
#product_skus_count(product_id, options = {}) ⇒ Object
returns the number of skus for the given product
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 758
|
#product_video(product_id, id, options = {}) ⇒ Object
gets the video with the given id for the given product
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 706
|
#product_videos(product_id, options = {}) ⇒ Object
gets a list of videos for the given product
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 701
|
#product_videos_count(product_id, options = {}) ⇒ Object
returns the number of videos for the given product
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 727
|
#products(options = {}) ⇒ Object
gets a list of products
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 522
|
#products_count(options = {}) ⇒ Object
returns the number of products
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 543
|
#redirect(id, options = {}) ⇒ Object
gets the redirect with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 767
|
#redirects(options = {}) ⇒ Object
gets a list of redirects
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 763
|
#redirects_count(options = {}) ⇒ Object
returns the number of redirects
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 784
|
#shipping_zone(id, options = {}) ⇒ Object
gets the shipping zone with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 818
|
#shipping_zone_method(zone_id, id, options = {}) ⇒ Object
gets the shipping method with the given id for the given shipping zone
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 793
|
#shipping_zone_methods(zone_id, options = {}) ⇒ Object
gets a list of shipping methods for the given shipping zone
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 788
|
#shipping_zones(options = {}) ⇒ Object
gets a list of shipping zones
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 814
|
#store_information ⇒ Object
get basic store information
14 15 16 |
# File 'lib/bigcommerce-oauth-api/client.rb', line 14 def store_information get('store') end |
#tax_class(id, options = {}) ⇒ Object
gets the tax_class with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 839
|
#tax_classes(options = {}) ⇒ Object
gets a list of tax_classes
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 835
|
#time ⇒ Object
get server time
8 9 10 |
# File 'lib/bigcommerce-oauth-api/client.rb', line 8 def time get('time') end |
#update_banner(id, options = {}) ⇒ Object
updates the attributes of the banner with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 247
|
#update_blog_post(id, options = {}) ⇒ Object
updates the attributes of the blog post with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 77
|
#update_brand(id, options = {}) ⇒ Object
updates the attributes of the brand with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 102
|
#update_category(id, options = {}) ⇒ Object
updates the attributes of the category with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 127
|
#update_coupon(id, options = {}) ⇒ Object
updates the attributes of the coupon with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 268
|
#update_customer(id, options = {}) ⇒ Object
updates the attributes of the customer with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 148
|
#update_customer_address(customer_id, id, options = {}) ⇒ Object
updates the attributes of the address with the given id for the given customer
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 176
|
#update_customer_group(id, options = {}) ⇒ Object
updates the attributes of the customer_group with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 199
|
#update_gift_certificate(id, options = {}) ⇒ Object
updates the attributes of the gift_certificate with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 293
|
#update_hook(id, options = {}) ⇒ Object
updates the attributes of the hook with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 855
|
#update_option(id, options = {}) ⇒ Object
updates the attributes of the option with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 314
|
#update_option_set(id, options = {}) ⇒ Object
updates the attributes of the option_set with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 339
|
#update_option_set_option(option_set_id, id, options = {}) ⇒ Object
updates the attributes of the option with the given id for the given option_set
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 367
|
#update_option_value(option_id, id, options = {}) ⇒ Object
updates the attributes of the value with the given id for the given option
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 393
|
#update_order(id, options = {}) ⇒ Object
updates the attributes of the order with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 424
|
#update_order_shipment(order_id, id, options = {}) ⇒ Object
updates the attributes of the shipment with the given id for the given order
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 487
|
#update_product(id, options = {}) ⇒ Object
updates the attributes of the product with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 534
|
#update_product_custom_field(product_id, id, options = {}) ⇒ Object
updates the attributes of the custom_field with the given id for the given product
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 562
|
#update_product_discount_rule(product_id, id, options = {}) ⇒ Object
updates the attributes of the discount_rule with the given id for the given product
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 588
|
#update_product_image(product_id, id, options = {}) ⇒ Object
updates the attributes of the image with the given id for the given product
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 639
|
#update_product_rule(product_id, id, options = {}) ⇒ Object
updates the attributes of the rule with the given id for the given product
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 685
|
#update_product_sku(product_id, id, options = {}) ⇒ Object
updates the attributes of the sku with the given id for the given product
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 747
|
#update_product_video(product_id, id, options = {}) ⇒ Object
updates the attributes of the video with the given id for the given product
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 716
|
#update_redirect(id, options = {}) ⇒ Object
updates the attributes of the redirect with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 775
|
#update_shipping_zone(id, options = {}) ⇒ Object
updates the attributes of the shipping zone with the given id
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 826
|
#update_shipping_zone_method(zone_id, id, options = {}) ⇒ Object
updates the attributes of the shipping method with the given id for the given shipping zone
|
|
# File 'lib/bigcommerce-oauth-api/client.rb', line 803
|