Class: BigcommerceOAuthAPI::Client
- Defined in:
- lib/bigcommerce-oauth-api/client.rb
Instance Method Summary collapse
-
#product_googleproductsearch(product_id, options = {}) ⇒ Object
Gets the Google Product Search mappings for a product.
-
#store_information ⇒ Object
get basic store information.
-
#time ⇒ Object
get server time.
Methods inherited from API
#config, #initialize, #is_legacy?
Methods included from Request
Constructor Details
This class inherits a constructor from BigcommerceOAuthAPI::API
Instance Method Details
#product_googleproductsearch(product_id, options = {}) ⇒ Object
Gets the Google Product Search mappings for a product.
20 21 22 |
# File 'lib/bigcommerce-oauth-api/client.rb', line 20 def product_googleproductsearch(product_id, = {}) get("products/#{product_id}/googleproductsearch", ) end |
#store_information ⇒ Object
get basic store information
14 15 16 |
# File 'lib/bigcommerce-oauth-api/client.rb', line 14 def store_information get('store') end |
#time ⇒ Object
get server time
8 9 10 |
# File 'lib/bigcommerce-oauth-api/client.rb', line 8 def time get('time') end |